@@ -1,8 +1,6 @@
 #!/usr/bin/env python3
 # Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
 
-from __future__ import annotations
-
 import os
 import types
 import warnings
@@ -284,7 +282,7 @@ class PrivacyEngine:
                 noise /= batch_size
             p.grad += noise
 
-    def to(self, device: Union[str, torch.device]) -> PrivacyEngine:
+    def to(self, device: Union[str, torch.device]):
         """
         Moves the privacy engine to the target device.
 
@@ -381,7 +379,7 @@ class PrivacyEngine:
             the generated noise with noise zero and standard
             deviation of ``noise_multiplier x max_grad_norm ``
         """
-        if self.noise_multiplier > 0:
+        if self.noise_multiplier > 0 and max_grad_norm > 0:
             return torch.normal(
                 0,
                 self.noise_multiplier * max_grad_norm,
